Summary:	Enhanced Doom engine
Name:		gzdoom
Version:	4.11.3
Release:	%mkrel 2
License:	GPLv3+
Group:		Games/Arcade
Url:		https://zdoom.org/
Source0:	https://github.com/ZDoom/gzdoom/archive/g%{version}/%{name}-%{version}.tar.gz
# From http://forum.zdoom.org/viewtopic.php?f=4&t=33119
Source1:	gzdoom.png
Patch1:		0001-Fix-file-paths.patch
Patch3:		gzdoom-static-libminiz.patch
# From opensuse
Patch10:	gzdoom-waddir.patch
Patch11:	gzdoom-discord.patch
ExclusiveArch:	aarch64 x86_64

BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	re2c
#BuildRequires:	lemon
BuildRequires:	imagemagick
BuildRequires:	libgomp-devel
BuildRequires:	cmake(ZMusic)
BuildRequires:	cmake(WebP)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(discord-rpc)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(vpx)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(zlib)
Requires:	timidity++

Recommends:	doom-iwad
Recommends:	fluid-soundfont-gs
Provides:	doom-engine

Obsoletes:	prboom-plus <= 2.5.4.1

%description
GZDoom is a Doom source port based on ZDoom. It features an
OpenGL 4.5 renderer and lots of new features, among them:
- 3D floors
- Dynamic lights
- Quake2/Unreal style skyboxes
- True color texture support
- Model support (limited at the moment)

Warning! Make sure to place WAD files to %{_gamesdatadir}/doom/

%files
%license LICENSE
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}
%{_gamesdatadir}/doom/brightmaps.pk3
%{_gamesdatadir}/doom/game_support.pk3
%{_gamesdatadir}/doom/game_widescreen_gfx.pk3
%{_gamesdatadir}/doom/gzdoom.pk3
%{_gamesdatadir}/doom/lights.pk3
%{_gamesdatadir}/doom/fm_banks/
%dir %{_gamesdatadir}/doom/soundfonts
%{_gamesdatadir}/doom/soundfonts/gzdoom.sf2
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-g%{version}

sed -i s,"<unknown version>","%{version}",g tools/updaterevision/UpdateRevision.cmake

# use system re2c
rm -rf tools/re2c
sed -i -e '/re2c/s/add_subdirectory/#add_subdirectory/g' tools/CMakeLists.txt
sed -i -e '/DEPENDS/s/\s\+re2c//g' src/CMakeLists.txt

%if 0
# use system lemon
rm -rf tools/lemon
sed -i -e '/lemon/s/add_subdirectory/#add_subdirectory/g' tools/CMakeLists.txt
sed -i -e '/DEPENDS/s/\s\+lemon//g' src/CMakeLists.txt
sed -i -e '/COMMAND/s/lemon -C/lemon -d/g' src/CMakeLists.txt
%endif

%build
%cmake -GNinja \
	-DINSTALL_PK3_PATH=%{_gamesdatadir}/doom/ \
	-DINSTALL_SOUNDFONT_PATH=%{_gamesdatadir}/doom \
	-DDYN_OPENAL=OFF
%cmake_build

%install
%cmake_install

# install menu entry
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=GZDoom
Comment=Enhanced Doom engine
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
EOF

# install menu icons
for N in 16 32 48 64 128;
do
convert %{SOURCE1} -scale ${N}x${N} $N.png;
install -D -m 0644 $N.png %{buildroot}%{_iconsdir}/hicolor/${N}x${N}/apps/%{name}.png
done

install -m 0644 README.md %{buildroot}%{_docdir}/%{name}/


%changelog
* Sun Jan 12 2025 daviddavid <daviddavid> 4.11.3-2.mga10
+ Revision: 2138622
- rebuild for new libvpx 1.14.1

* Sun Jan 28 2024 wally <wally> 4.11.3-1.mga10
+ Revision: 2035555
- new version 4.11.3
- use system re2c

* Sun Oct 15 2023 daviddavid <daviddavid> 4.11.1-1.mga10
+ Revision: 1996980
- new version: 4.11.1
- fix libminiz as static lib

* Tue Oct 10 2023 danf <danf> 4.11.0-1.mga10
+ Revision: 1994014
- Update to ver. 4.11.0

* Tue Feb 28 2023 daviddavid <daviddavid> 4.10.0-1.mga9
+ Revision: 1945760
- new version: 4.10.0
- add mageia specific patch as compilation picked a system installed "types.h"
  include instead of the upstream source one in "/src/common/scripting/core/types.h"
  see: https://github.com/ZDoom/gzdoom/issues/2018
- fix WAD files installation path in description
- use system zmusic and discord-rpc new dependencies
- fuildsynth is no more needed
- update files list

* Fri Apr 01 2022 umeabot <umeabot> 4.3.3-3.mga9
+ Revision: 1839180
- Mageia 9 Mass Rebuild

* Sun Mar 15 2020 zezinho <zezinho> 4.3.3-2.mga8
+ Revision: 1556435
- add recommends so that game music can be heard

* Fri Mar 13 2020 zezinho <zezinho> 4.3.3-1.mga8
+ Revision: 1556154
- new version

* Mon Feb 17 2020 umeabot <umeabot> 4.2.4-2.mga8
+ Revision: 1537531
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Nov 04 2019 zezinho <zezinho> 4.2.4-1.mga8
+ Revision: 1457685
- new version 4.2.4
- upstream does not support i586, as OpenGL 4.5 did not exist in such hardware
- new version 4.2.1

* Sun Aug 26 2018 zezinho <zezinho> 3.5.0-2.mga7
+ Revision: 1254759
- obsoletes prboom-plus

* Sun Aug 26 2018 zezinho <zezinho> 3.5.0-1.mga7
+ Revision: 1254689
- started from rosalabs spec
- imported package gzdoom



* Wed Feb 07 2018 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3.2.5-1
- (62d179b) New version 3.2.5
- (62d179b) No longer depends on non-free packages


